==> libquicktime-0.9.9.tar.gz: libquicktime-0.9.9/plugins/rtjpeg/rtjpeg_codec.h <==
/* 
 * rtjpeg.h (C) Justin Schoeman 2002 (justin@suntiger.ee.up.ac.za)
 * Based entirely upon qtpng.h from libquicktime 
 * (http://libquicktime.sf.net).
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/*
 *  Support for video, which is no multiple of 16 by
 *  Burkhard Plaum
 */

#ifndef QUICKTIME_RTJPEG_H
#define QUICKTIME_RTJPEG_H

#include "RTjpeg.h"
#include <quicktime/quicktime.h>

typedef struct
{
        uint8_t ** rows;
        int rowspan, rowspan_uv;

	/* Compression stuff */
	RTjpeg_t * compress_struct;
	uint8_t * write_buffer;
	int Q;
	int K;
	int LQ;
	int CQ;
	
	/* DeCompression stuff */
	RTjpeg_t * decompress_struct;
	uint8_t * read_buffer;
	int read_buffer_size;
        int jpeg_width;
        int jpeg_height;
        int qt_width;
        int qt_height;
} quicktime_rtjpeg_codec_t;

#endif

void quicktime_init_codec_rtjpeg(quicktime_video_map_t *vtrack);

==> libquicktime-0.9.10.tar.gz: libquicktime-0.9.10/plugins/rtjpeg/rtjpeg_codec.h <==
/* 
 * rtjpeg.h (C) Justin Schoeman 2002 (justin@suntiger.ee.up.ac.za)
 * Based entirely upon qtpng.h from libquicktime 
 * (http://libquicktime.sf.net).
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/*
 *  Support for video, which is no multiple of 16 by
 *  Burkhard Plaum
 */

#ifndef QUICKTIME_RTJPEG_H
#define QUICKTIME_RTJPEG_H

#include "RTjpeg.h"
#include <quicktime/quicktime.h>

typedef struct
{
        uint8_t ** rows;
        int rowspan, rowspan_uv;

	/* Compression stuff */
	RTjpeg_t * compress_struct;
	uint8_t * write_buffer;
	int Q;
	int K;
	int LQ;
	int CQ;
	
	/* DeCompression stuff */
	RTjpeg_t * decompress_struct;
	uint8_t * read_buffer;
	int read_buffer_alloc;
        int jpeg_width;
        int jpeg_height;
        int qt_width;
        int qt_height;
} quicktime_rtjpeg_codec_t;

#endif

void quicktime_init_codec_rtjpeg(quicktime_video_map_t *vtrack);
